local config = require("modules/utils/config")

local settings = {
	nativeOptions = {},
	nuiInstalled = false,
	nui = nil
}

function settings.setupNative(mod)
	local nativeSettings = GetMod("nativeSettings")
	settings.nui = nativeSettings

	if not nativeSettings then
		print("[FreeFly] Info: NativeSettings lib not found, use the ImGui UI instead!")
		return
	end

	local cetVer = tonumber((GetVersion():gsub('^v(%d+)%.(%d+)%.(%d+)(.*)', function(major, minor, patch, wip) -- <-- This has been made by psiberx, all credits to him
		return ('%d.%02d%02d%d'):format(major, minor, patch, (wip == '' and 0 or 1))
	end)))

	if cetVer < 1.18 then
		print("[FreeFly] Error: CET version below recommended!")
		return
	end

	settings.nuiInstalled = true

	nativeSettings.addTab("/freefly", "Vol & Noclip")
	nativeSettings.addSubcategory("/freefly/gen", "Réglages Généraux")

	settings.nativeOptions["speed"] = nativeSettings.addRangeFloat("/freefly/gen", "Vitesse de vol", "Contrôle la vitesse à laquelle vous volez", 0.01, 50, 0.01, "%.2f", mod.settings.speed,  mod.defaultSettings.speed, function(value)
		mod.settings.speed = value
		config.saveFile("config/config.json", mod.settings)
	end)

	settings.nativeOptions["speedIncrementStep"] = nativeSettings.addRangeFloat("/freefly/gen", "Incrémentation de vitesse", "Il s'agit de la valeur par laquelle la vitesse est augmentée / diminuée lors du défilement de la molette", 0, 5, 0.01, "%.2f",  mod.settings.speedIncrementStep,  mod.defaultSettings.speedIncrementStep, function(value)
		mod.settings.speedIncrementStep = value
		config.saveFile("config/config.json", mod.settings)
	end)

	settings.nativeOptions["angle"] = nativeSettings.addRangeFloat("/freefly/gen", "Angle de braquage", "Changer cette valeur vous fait voler dans des courbes / cercles", -4, 5, 0.01, "%.2f", mod.settings.angle,  mod.defaultSettings.angle, function(value)
		mod.settings.angle = value
		config.saveFile("config/config.json", mod.settings)
	end)

	settings.nativeOptions["noWeapon"] = nativeSettings.addSwitch("/freefly/gen", "Désactiver les armes en vol", "Utilisez cette option pour désactiver les armes pendant le vol (la molette servant à changer de vitesse de vol)",  mod.settings.noWeapon,  mod.defaultSettings.noWeapon, function(state)
		mod.settings.noWeapon = state
		config.saveFile("config/config.json", mod.settings)
	end)

	settings.nativeOptions["timeStop"] = nativeSettings.addSwitch("/freefly/gen", "Arrêt du temps pendant le vol", "Cochez cette option si vous souhaitez arrêter le temps pendant le vol",  mod.settings.timeStop,  mod.defaultSettings.timeStop, function(state)
		mod.settings.timeStop = state
		config.saveFile("config/config.json", mod.settings)
	end)

	settings.nativeOptions["noController"] = nativeSettings.addSwitch("/freefly/gen", "Désactiver la prise en charge du contrôleur", "Cochez cette option pour désactiver la possibilité d'activer le mode vol à l'aide d'une manette", mod.settings.noController,	 mod.defaultSettings.noController, function(state)
		mod.settings.noController = state
		config.saveFile("config/config.json", mod.settings)
	end)
end

return settings